--- a/calendarui/controller/src/caleneditui.cpp Wed Apr 14 15:55:57 2010 +0300
+++ b/calendarui/controller/src/caleneditui.cpp Tue Apr 27 16:36:22 2010 +0300
@@ -152,7 +152,14 @@
TUid currentView = iController.ViewManager().CurrentView();
if( KUidCalenTodoView == currentView )
{
- // Open NewEntry as "To-Do", if editor is launched from To-Do view.
+ // Open NewEntry as "To-Do", if editor is launched from To-Do view.
+ MCalenContext& context = iController.Services().Context();
+ // Set the date on the context to today.
+ TTime homeTime;
+ homeTime.HomeTime();
+ TCalTime today;
+ today.SetTimeLocalL( homeTime );
+ context.SetFocusDateL( today, TVwsViewId( KUidCalendar, KUidCalenTodoView ) );
EditNewEntryL( CCalEntry::ETodo );
}
else